@@ -1,5 +1,5 @@
 from .about import __title__, __version__  # noqa: F401
 from .components.quality import QualityThresholds  # noqa: F401
-from .extract import extract_df, extract_dict  # noqa: F401
+from .extractors import extract_df, extract_dict, extract_metrics  # noqa: F401
 from .load_components import TextDescriptives  # noqa: F401
-from .utils import get_assigns, get_valid_metrics  # noqa: F401
+from .utils import get_doc_assigns, get_valid_metrics  # noqa: F401
